@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: commands.c,v 1.51 1998/06/20 20:21:31 kalt Exp $";
+static char rcsid[] = "@(#)$Id: commands.c,v 1.52 1998/06/25 15:54:21 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -470,13 +470,19 @@ int
 cmd_option(p)
   char *p;
 {
-  char *c, *channel = NULL, *v;
+  static char *channel = NULL;
+  char *c, *v;
   unsigned int flag, all = 0;
   int fnum = -1;
 
   if (!*p)
       return -1;
 
+  if (channel)
+    {
+      free(channel);
+      channel = NULL;
+    }
   if (v = index(p, ' '))
       *v++ = '\0';
 
