@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: display.c,v 1.47 1998/06/20 21:16:04 kalt Exp $";
+static char rcsid[] = "@(#)$Id: display.c,v 1.51 1998/06/25 18:36:35 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -451,7 +451,11 @@ sic_format(sender, cmd, dest, para)
 	      switch (n)
 		{
 	      case 1:
+		  if (server->sname)
+		      free(server->sname);
 		  server->sname = strdup(s);
+		  if (server->nick)
+		      free(server->nick);
 		  server->nick = strdup(d);
 		  if (!strcasecmp(s, server->sname))
 		      locals = 1;
@@ -482,7 +486,7 @@ sic_format(sender, cmd, dest, para)
 			  proto = P_D;
 			  ch2 = "Dalnet";
 			}
-		      if (strstr(ch1, "+CSr") || strstr(ch1, "/hybrid"))
+		      else if (strstr(ch1, "+CSr") || strstr(ch1, "/hybrid"))
 			{
 			  proto = P_E;
 			  ch2 = "EFnet";
@@ -602,7 +606,16 @@ sic_format(sender, cmd, dest, para)
 	      del_channel(NULL);
 	    }
 	  else if (!strcasecmp("INVITE", cmd))
+	    {
+	      struct channel_ *ctmp;
+
 	      fmt = F_INVITE;
+	      if ((ctmp = get_channel(p)) && option(ctmp->copt, C_REJOIN))
+		{
+		  vsic_slog(LOG_CLIENT, "--- Answering invitation to %s.", p);
+		  join_channel(p, 0);
+		}
+	    }
 	  else if (!strcasecmp("JOIN", cmd))
 	    {
 	      fmt = F_JOIN;
@@ -633,10 +646,13 @@ sic_format(sender, cmd, dest, para)
 	      assert(comment);
 	      fmt = F_KICK;
 	      *comment = '\0';
-	      if (strcasecmp(p, server->nick))
 		  del_member(d, p);
-	      else if (get_option(Z_REJOIN, d))
-		  rejoin_channel(d);
+	      if (!strcasecmp(p, server->nick))
+		{
+		  del_channel(d);
+		  if (get_option(Z_REJOIN, d))
+		      rejoin_channel(d);
+		}
 	      *comment = ' ';
 	    }
 	  else if (!strcasecmp("TOPIC", cmd))
