@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: server.c,v 1.50 1998/06/05 13:12:53 kalt Exp $";
+static char rcsid[] = "@(#)$Id: server.c,v 1.51 1998/06/25 18:15:56 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -905,7 +905,8 @@ sic_select()
 			  (server->pass) ? "\n" : "",
 			  stmp->nick,
 			  (stmp->uname) ? stmp->uname :
-			  	(wp = getenv("SICUSER")) ? wp : "sicuser",
+			  	(wp = getenv("SICUSER")) ? wp :
+			  		(wp = getenv("USER")) ? wp : "sicuser",
 			  (stmp->rname) ? stmp->rname :
 			  	(wp = getenv("SICNAME")) ? wp :"wasting time");
 		  if (write(stmp->fd, buffer, strlen(buffer)) == -1)
