@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: window.c,v 1.54 1998/06/13 00:54:04 kalt Exp $";
+static char rcsid[] = "@(#)$Id: window.c,v 1.56 1998/07/20 14:52:56 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -226,7 +226,7 @@ sic_dlog(force)
   time_t now = time(NULL);
   unsigned int cnt = 0, dcnt = 0;
 
-  if (!(current->flog && current->flog->flags & LOG_DEL))
+  if (!(current->flog && current->flog->flags & LOG_DEL) && (force == 0))
       return;
   while (tmpl)
     {
@@ -266,7 +266,10 @@ sic_dlog(force)
 	  dcnt++;
 	}
     }
+#if defined(DEBUG)
+  /* it's a memory leak when called from sic_wkill() */
   vsic_slog(LOG_DEBUG, "sic_dlog(%d): %u out of %u", force, dcnt, cnt);
+#endif
 }
 
 /* sic_clog: clear the lastlog for the current window */
@@ -403,7 +406,7 @@ display_status()
   struct channel_ *ctmp = clist;
   struct window_ *wtmp = wlist;
   int chcnt = 0;
-  char chbuf[5] = "", actbuf[40] = "", tbuf[6],
+  char chbuf[6] = "", actbuf[40] = "", tbuf[6],
        buf[160]; /* hmmpf */
 
   my_strftime(tbuf, 6, "%H:%M");
@@ -639,7 +642,7 @@ sic_wkill()
     {
       struct window_ **wtmp = &wlist, *wdel;
 
-      sic_clog();
+      sic_clog(1);
       while (*wtmp != current)
 	  wtmp = &((*wtmp)->nextw);
       wdel = *wtmp;
@@ -659,7 +662,7 @@ sic_wkill()
       if (option(wdel->wopt, W_DCC))
 	  set_option(wdel->nextw->wopt, W_DCC);
       opt_free(&(wdel->custw));
-      free(wdel); /* hmmpf -LEAK , where ? */
+      free(wdel);
 
       win_cnt -= 1;
 
